Imports System
Imports System.Data
Imports NorthwindWinFormViewsDynamic_VB.DataLayer
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject
Imports NorthwindWinFormViewsDynamic_VB.Models
Imports System.Runtime.InteropServices

Namespace BusinessObject.Base

     ''' <summary>
     ''' Base class for QuarterlyOrders.  Do not make changes to this class,
     ''' instead, put additional code in the QuarterlyOrders class
     ''' </summary>
     Public Class QuarterlyOrdersBase
         ' private members
         Private _customerID As String
         Private _companyName As String
         Private _city As String
         Private _country As String

         ''' <summary>
         ''' Gets or Sets CustomerID
         ''' </summary>
         Public Property CustomerID() As String
             Get
                 Return _customerID
             End Get
             Set(ByVal value As String)
                 _customerID = value
             End Set
         End Property

         ''' <summary>
         ''' Gets or Sets CompanyName
         ''' </summary>
         Public Property CompanyName() As String
             Get
                 Return _companyName
             End Get
             Set(ByVal value As String)
                 _companyName = value
             End Set
         End Property

         ''' <summary>
         ''' Gets or Sets City
         ''' </summary>
         Public Property City() As String
             Get
                 Return _city
             End Get
             Set(ByVal value As String)
                 _city = value
             End Set
         End Property

         ''' <summary>
         ''' Gets or Sets Country
         ''' </summary>
         Public Property Country() As String
             Get
                 Return _country
             End Get
             Set(ByVal value As String)
                 _country = value
             End Set
         End Property


         ''' <summary>
         ''' Constructor
         ''' </summary>
         Public Sub New()
         End Sub

         ''' <summary>
         ''' Gets the total number of records in the QuarterlyOrders table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Return QuarterlyOrdersDataLayer.GetRecordCount()
         End Function

         ''' <summary>
         ''' Selects records as a collection (List) of QuarterlyOrders sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         ''' </summary>
         Public Shared Function SelectSkipAndTake(rows As Integer, startRowIndex As Integer, <Out()> ByRef totalRowCount As Integer, sortByExpression As String) As QuarterlyOrdersCollection
             totalRowCount = GetRecordCount()
             sortByExpression = GetSortExpression(sortByExpression)

             Return QuarterlyOrdersDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Selects records as a collection (List) of QuarterlyOrders sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex.  Use for non model-binded gridview control.  Does not return total row count.
         ''' </summary>
         Public Shared Function SelectSkipAndTake(rows As Integer, startRowIndex As Integer, sortByExpression As String) As QuarterlyOrdersCollection
             sortByExpression = GetSortExpression(sortByExpression)
             Return QuarterlyOrdersDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows)
         End Function

         Private Shared Function GetSortExpression(sortByExpression As String) As String
             If [String].IsNullOrEmpty(sortByExpression) Or sortByExpression = " asc" Then
                 sortByExpression = "CustomerID"
             Else If sortByExpression.Contains(" asc") Then
                 sortByExpression = sortByExpression.Replace(" asc", "")
             End If

             Return sortByExpression
         End Function

         ''' <summary>
         ''' Compares CustomerID used for sorting
         ''' </summary>
         Public Shared ByCustomerID As Comparison(Of QuarterlyOrders) =
         Function(ByVal x As QuarterlyOrders, ByVal y As QuarterlyOrders)
             Dim value1 As String = If(x.CustomerID, String.Empty)
             Dim value2 As String = If(y.CustomerID, String.Empty)
             Return value1.CompareTo(value2)
         End Function

         ''' <summary>
         ''' Compares CompanyName used for sorting
         ''' </summary>
         Public Shared ByCompanyName As Comparison(Of QuarterlyOrders) =
         Function(ByVal x As QuarterlyOrders, ByVal y As QuarterlyOrders)
             Dim value1 As String = If(x.CompanyName, String.Empty)
             Dim value2 As String = If(y.CompanyName, String.Empty)
             Return value1.CompareTo(value2)
         End Function

         ''' <summary>
         ''' Compares City used for sorting
         ''' </summary>
         Public Shared ByCity As Comparison(Of QuarterlyOrders) =
         Function(ByVal x As QuarterlyOrders, ByVal y As QuarterlyOrders)
             Dim value1 As String = If(x.City, String.Empty)
             Dim value2 As String = If(y.City, String.Empty)
             Return value1.CompareTo(value2)
         End Function

         ''' <summary>
         ''' Compares Country used for sorting
         ''' </summary>
         Public Shared ByCountry As Comparison(Of QuarterlyOrders) =
         Function(ByVal x As QuarterlyOrders, ByVal y As QuarterlyOrders)
             Dim value1 As String = If(x.Country, String.Empty)
             Dim value2 As String = If(y.Country, String.Empty)
             Return value1.CompareTo(value2)
         End Function

     End Class
End Namespace
