Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for InvoicesDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the InvoicesDataLayer class
     ''' </summary>
     Public Class InvoicesDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As InvoicesCollection
              Dim objInvoicesCol As InvoicesCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objInvoicesCol = New InvoicesCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objInvoices As Invoices = CreateInvoicesFromDataRowShared(dr)
                                      objInvoicesCol.Add(objInvoices)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objInvoicesCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the Invoices table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = InvoicesSql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects Invoices records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As InvoicesCollection
             Dim dynamicSqlScript As String = InvoicesSql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a Invoices object from the passed data row
         ''' </summary>
         Private Shared Function CreateInvoicesFromDataRowShared(dr As DataRow) As Invoices
             Dim objInvoices As Invoices = New Invoices()


             If Not DbNull.Value.Equals(dr("ShipName")) Then
                 objInvoices.ShipName = dr("ShipName").ToString()
             Else
                 objInvoices.ShipName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipAddress")) Then
                 objInvoices.ShipAddress = dr("ShipAddress").ToString()
             Else
                 objInvoices.ShipAddress = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipCity")) Then
                 objInvoices.ShipCity = dr("ShipCity").ToString()
             Else
                 objInvoices.ShipCity = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipRegion")) Then
                 objInvoices.ShipRegion = dr("ShipRegion").ToString()
             Else
                 objInvoices.ShipRegion = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipPostalCode")) Then
                 objInvoices.ShipPostalCode = dr("ShipPostalCode").ToString()
             Else
                 objInvoices.ShipPostalCode = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipCountry")) Then
                 objInvoices.ShipCountry = dr("ShipCountry").ToString()
             Else
                 objInvoices.ShipCountry = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CustomerID")) Then
                 objInvoices.CustomerID = dr("CustomerID").ToString()
             Else
                 objInvoices.CustomerID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CustomerName")) Then
                 objInvoices.CustomerName = dr("CustomerName").ToString()
             Else
                 objInvoices.CustomerName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Address")) Then
                 objInvoices.Address = dr("Address").ToString()
             Else
                 objInvoices.Address = Nothing
             End If

             If Not DbNull.Value.Equals(dr("City")) Then
                 objInvoices.City = dr("City").ToString()
             Else
                 objInvoices.City = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Region1")) Then
                 objInvoices.Region1 = dr("Region1").ToString()
             Else
                 objInvoices.Region1 = Nothing
             End If

             If Not DbNull.Value.Equals(dr("PostalCode")) Then
                 objInvoices.PostalCode = dr("PostalCode").ToString()
             Else
                 objInvoices.PostalCode = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Country")) Then
                 objInvoices.Country = dr("Country").ToString()
             Else
                 objInvoices.Country = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Salesperson")) Then
                 objInvoices.Salesperson = dr("Salesperson").ToString()
             Else
                 objInvoices.Salesperson = Nothing
             End If

             If Not DbNull.Value.Equals(dr("OrderID")) Then
                 objInvoices.OrderID = DirectCast(dr("OrderID"), Integer)
             Else
                 objInvoices.OrderID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("OrderDate")) Then
                 objInvoices.OrderDate = DirectCast(dr("OrderDate"), Date)
             Else
                 objInvoices.OrderDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("RequiredDate")) Then
                 objInvoices.RequiredDate = DirectCast(dr("RequiredDate"), Date)
             Else
                 objInvoices.RequiredDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShippedDate")) Then
                 objInvoices.ShippedDate = DirectCast(dr("ShippedDate"), Date)
             Else
                 objInvoices.ShippedDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipperName")) Then
                 objInvoices.ShipperName = dr("ShipperName").ToString()
             Else
                 objInvoices.ShipperName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductID")) Then
                 objInvoices.ProductID = DirectCast(dr("ProductID"), Integer)
             Else
                 objInvoices.ProductID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductName")) Then
                 objInvoices.ProductName = dr("ProductName").ToString()
             Else
                 objInvoices.ProductName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("UnitPrice")) Then
                 objInvoices.UnitPrice = DirectCast(dr("UnitPrice"), Decimal)
             Else
                 objInvoices.UnitPrice = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Quantity")) Then
                 objInvoices.Quantity = DirectCast(dr("Quantity"), Short)
             Else
                 objInvoices.Quantity = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Discount")) Then
                 objInvoices.Discount = DirectCast(dr("Discount"), Single)
             Else
                 objInvoices.Discount = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ExtendedPrice")) Then
                 objInvoices.ExtendedPrice = DirectCast(dr("ExtendedPrice"), Decimal)
             Else
                 objInvoices.ExtendedPrice = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Freight")) Then
                 objInvoices.Freight = DirectCast(dr("Freight"), Decimal)
             Else
                 objInvoices.Freight = Nothing
             End If

             Return objInvoices
         End Function
     End Class
End Namespace
