Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for OrdersQryDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the OrdersQryDataLayer class
     ''' </summary>
     Public Class OrdersQryDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As OrdersQryCollection
              Dim objOrdersQryCol As OrdersQryCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objOrdersQryCol = New OrdersQryCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objOrdersQry As OrdersQry = CreateOrdersQryFromDataRowShared(dr)
                                      objOrdersQryCol.Add(objOrdersQry)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objOrdersQryCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the OrdersQry table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = OrdersQrySql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects OrdersQry records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As OrdersQryCollection
             Dim dynamicSqlScript As String = OrdersQrySql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a OrdersQry object from the passed data row
         ''' </summary>
         Private Shared Function CreateOrdersQryFromDataRowShared(dr As DataRow) As OrdersQry
             Dim objOrdersQry As OrdersQry = New OrdersQry()


             If Not DbNull.Value.Equals(dr("OrderID")) Then
                 objOrdersQry.OrderID = DirectCast(dr("OrderID"), Integer)
             Else
                 objOrdersQry.OrderID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CustomerID")) Then
                 objOrdersQry.CustomerID = dr("CustomerID").ToString()
             Else
                 objOrdersQry.CustomerID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("EmployeeID")) Then
                 objOrdersQry.EmployeeID = DirectCast(dr("EmployeeID"), Integer)
             Else
                 objOrdersQry.EmployeeID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("OrderDate")) Then
                 objOrdersQry.OrderDate = DirectCast(dr("OrderDate"), Date)
             Else
                 objOrdersQry.OrderDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("RequiredDate")) Then
                 objOrdersQry.RequiredDate = DirectCast(dr("RequiredDate"), Date)
             Else
                 objOrdersQry.RequiredDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShippedDate")) Then
                 objOrdersQry.ShippedDate = DirectCast(dr("ShippedDate"), Date)
             Else
                 objOrdersQry.ShippedDate = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipVia")) Then
                 objOrdersQry.ShipVia = DirectCast(dr("ShipVia"), Integer)
             Else
                 objOrdersQry.ShipVia = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Freight")) Then
                 objOrdersQry.Freight = DirectCast(dr("Freight"), Decimal)
             Else
                 objOrdersQry.Freight = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipName")) Then
                 objOrdersQry.ShipName = dr("ShipName").ToString()
             Else
                 objOrdersQry.ShipName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipAddress")) Then
                 objOrdersQry.ShipAddress = dr("ShipAddress").ToString()
             Else
                 objOrdersQry.ShipAddress = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipCity")) Then
                 objOrdersQry.ShipCity = dr("ShipCity").ToString()
             Else
                 objOrdersQry.ShipCity = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipRegion")) Then
                 objOrdersQry.ShipRegion = dr("ShipRegion").ToString()
             Else
                 objOrdersQry.ShipRegion = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipPostalCode")) Then
                 objOrdersQry.ShipPostalCode = dr("ShipPostalCode").ToString()
             Else
                 objOrdersQry.ShipPostalCode = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ShipCountry")) Then
                 objOrdersQry.ShipCountry = dr("ShipCountry").ToString()
             Else
                 objOrdersQry.ShipCountry = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CompanyName")) Then
                 objOrdersQry.CompanyName = dr("CompanyName").ToString()
             Else
                 objOrdersQry.CompanyName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Address")) Then
                 objOrdersQry.Address = dr("Address").ToString()
             Else
                 objOrdersQry.Address = Nothing
             End If

             If Not DbNull.Value.Equals(dr("City")) Then
                 objOrdersQry.City = dr("City").ToString()
             Else
                 objOrdersQry.City = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Region1")) Then
                 objOrdersQry.Region1 = dr("Region1").ToString()
             Else
                 objOrdersQry.Region1 = Nothing
             End If

             If Not DbNull.Value.Equals(dr("PostalCode")) Then
                 objOrdersQry.PostalCode = dr("PostalCode").ToString()
             Else
                 objOrdersQry.PostalCode = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Country")) Then
                 objOrdersQry.Country = dr("Country").ToString()
             Else
                 objOrdersQry.Country = Nothing
             End If

             Return objOrdersQry
         End Function
     End Class
End Namespace
