Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for ProductsByCategoryDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the ProductsByCategoryDataLayer class
     ''' </summary>
     Public Class ProductsByCategoryDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As ProductsByCategoryCollection
              Dim objProductsByCategoryCol As ProductsByCategoryCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objProductsByCategoryCol = New ProductsByCategoryCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objProductsByCategory As ProductsByCategory = CreateProductsByCategoryFromDataRowShared(dr)
                                      objProductsByCategoryCol.Add(objProductsByCategory)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objProductsByCategoryCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the ProductsByCategory table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = ProductsByCategorySql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects ProductsByCategory records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As ProductsByCategoryCollection
             Dim dynamicSqlScript As String = ProductsByCategorySql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a ProductsByCategory object from the passed data row
         ''' </summary>
         Private Shared Function CreateProductsByCategoryFromDataRowShared(dr As DataRow) As ProductsByCategory
             Dim objProductsByCategory As ProductsByCategory = New ProductsByCategory()


             If Not DbNull.Value.Equals(dr("CategoryName")) Then
                 objProductsByCategory.CategoryName = dr("CategoryName").ToString()
             Else
                 objProductsByCategory.CategoryName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductName")) Then
                 objProductsByCategory.ProductName = dr("ProductName").ToString()
             Else
                 objProductsByCategory.ProductName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("QuantityPerUnit")) Then
                 objProductsByCategory.QuantityPerUnit = dr("QuantityPerUnit").ToString()
             Else
                 objProductsByCategory.QuantityPerUnit = Nothing
             End If

             If Not DbNull.Value.Equals(dr("UnitsInStock")) Then
                 objProductsByCategory.UnitsInStock = DirectCast(dr("UnitsInStock"), Short)
             Else
                 objProductsByCategory.UnitsInStock = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Discontinued")) Then
                 objProductsByCategory.Discontinued = DirectCast(dr("Discontinued"), Boolean)
             Else
                 objProductsByCategory.Discontinued = Nothing
             End If

             Return objProductsByCategory
         End Function
     End Class
End Namespace
