Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for QuarterlyOrdersDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the QuarterlyOrdersDataLayer class
     ''' </summary>
     Public Class QuarterlyOrdersDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As QuarterlyOrdersCollection
              Dim objQuarterlyOrdersCol As QuarterlyOrdersCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objQuarterlyOrdersCol = New QuarterlyOrdersCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objQuarterlyOrders As QuarterlyOrders = CreateQuarterlyOrdersFromDataRowShared(dr)
                                      objQuarterlyOrdersCol.Add(objQuarterlyOrders)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objQuarterlyOrdersCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the QuarterlyOrders table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = QuarterlyOrdersSql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects QuarterlyOrders records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As QuarterlyOrdersCollection
             Dim dynamicSqlScript As String = QuarterlyOrdersSql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a QuarterlyOrders object from the passed data row
         ''' </summary>
         Private Shared Function CreateQuarterlyOrdersFromDataRowShared(dr As DataRow) As QuarterlyOrders
             Dim objQuarterlyOrders As QuarterlyOrders = New QuarterlyOrders()


             If Not DbNull.Value.Equals(dr("CustomerID")) Then
                 objQuarterlyOrders.CustomerID = dr("CustomerID").ToString()
             Else
                 objQuarterlyOrders.CustomerID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CompanyName")) Then
                 objQuarterlyOrders.CompanyName = dr("CompanyName").ToString()
             Else
                 objQuarterlyOrders.CompanyName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("City")) Then
                 objQuarterlyOrders.City = dr("City").ToString()
             Else
                 objQuarterlyOrders.City = Nothing
             End If

             If Not DbNull.Value.Equals(dr("Country")) Then
                 objQuarterlyOrders.Country = dr("Country").ToString()
             Else
                 objQuarterlyOrders.Country = Nothing
             End If

             Return objQuarterlyOrders
         End Function
     End Class
End Namespace
