Imports System
Imports System.Windows.Forms
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject
Imports NorthwindWinFormViewsDynamic_VB.Domain

    Public Class ListReadOnlyOrdersQry
        Dim _currentRecordNumber As Integer = 1
        Dim _currentPageNumber As Integer = 1
        Dim _totalRecords As Integer = 0
        Dim _totalNumberOfPages As Integer = 0
        Dim _sortColumnIndex As Integer = 0
        Dim _sortByExpression As String = ""
        Dim _sortOrder As SortOrder = SortOrder.Ascending
        Dim _currentRowIndex As Integer
        Dim _isFireToolStripComboBoxSelectedIndexChanged As Boolean

        #Region "winform events"

        Private Sub ListReadOnlyOrdersQry_Load(sender As Object, e As EventArgs) Handles MyBase.Load
            SetGridProperties()
            SetGridColumnProperties()
            SetDataSource(False)
            ResetNavButtonsToDefault()

        End Sub

        #End Region

        #Region "binding navigator control events"

        Private Sub BnvNavMoveFirstItem_Click(sender As Object, e As EventArgs) Handles BnvNavMoveFirstItem.Click
            _currentRecordNumber = 1
            _currentPageNumber = 1
            MoveToFirstPage()
        End Sub

        Private Sub BnvNavMovePreviousItem_Click(sender As Object, e As EventArgs) Handles BnvNavMovePreviousItem.Click
            _currentPageNumber -= 1
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1))

            MoveToPrevious()
        End Sub

        Private Sub BnvNavMoveNextItem_Click(sender As Object, e As EventArgs) Handles BnvNavMoveNextItem.Click
            _currentPageNumber += 1
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1))

            MoveToNext()
        End Sub

        Private Sub BnvNavMoveLastItem_Click(sender As Object, e As EventArgs) Handles BnvNavMoveLastItem.Click
            _currentPageNumber = _totalNumberOfPages
            _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1))

            MoveToLastPage()
        End Sub


        #End Region

        #Region "data gridview events"

        Private Sub DgvGrid_ColumnHeaderMouseClick(sender As Object, e As DataGridViewCellMouseEventArgs) Handles DgvGrid.ColumnHeaderMouseClick
            _sortColumnIndex = e.ColumnIndex
            SetDataSource(True)
        End Sub

        Private Sub DgvGrid_CellContextMenuStripNeeded(sender As Object, e As DataGridViewCellContextMenuStripNeededEventArgs) Handles DgvGrid.CellContextMenuStripNeeded
            HightlightRow(e.RowIndex)
        End Sub

        Private Sub DgvGrid_CellClick(sender As Object, e As DataGridViewCellEventArgs) Handles DgvGrid.CellClick
            ' make sure the click did not come from the header
            If e.RowIndex <> -1 Then
                HightlightRow(e.RowIndex)
            End If
        End Sub

        #End Region

        #Region "toolstrip menu item events"

        Private Sub TscbPage_SelectedIndexChanged(sender As Object, e As EventArgs) Handles TscbPage.SelectedIndexChanged
            ' make sure this event is not called 
            ' when adding items to the tool strip combo box
            If Not _isFireToolStripComboBoxSelectedIndexChanged Then
                Return
            End If

            ' set current page number
            Dim lastVisitedPageNumber As Integer = _currentPageNumber
            _currentPageNumber = Cint(TscbPage.ComboBox.SelectedItem)

            If _currentPageNumber = 1 Then
                _currentRecordNumber = 1
            Else
                _currentRecordNumber = 1 + (ConstantHelper.GridNumberOfRows * (_currentPageNumber - 1))
            End If

            ' go to the selected page
            If _currentPageNumber = 1 Then
                MoveToFirstPage()
            Else If _currentPageNumber = _totalNumberOfPages Then
                MoveToLastPage()
            Else If _currentPageNumber < lastVisitedPageNumber Then
                MoveToPrevious()
            Else
                MoveToNext()
            End If
        End Sub

        #End Region

        #Region "private methods"

        Private Sub SetGridProperties()
            DgvGrid.AutoGenerateColumns = False
            DgvGrid.AllowUserToResizeRows = False
            DgvGrid.ColumnCount = 20
            DgvGrid.ScrollBars = ScrollBars.Horizontal
            DgvGrid.AllowUserToOrderColumns = False
            DgvGrid.AllowUserToAddRows = False
            DgvGrid.AllowUserToDeleteRows = False
            DgvGrid.ReadOnly = True
        End Sub

        Private Sub SetGridColumnProperties()
            DgvGrid.Columns("OrderID").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("CustomerID").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("EmployeeID").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("OrderDate").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("RequiredDate").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("ShippedDate").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("ShipVia").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("Freight").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleRight
            DgvGrid.Columns("Freight").DefaultCellStyle.Format = "0.00##"
            DgvGrid.Columns("ShipName").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("ShipAddress").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("ShipCity").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("ShipRegion").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("ShipPostalCode").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("ShipCountry").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("CompanyName").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("Address").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("City").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("Region1").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("PostalCode").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
            DgvGrid.Columns("Country").DefaultCellStyle.Alignment = DataGridViewContentAlignment.MiddleLeft
        End Sub

        Private Sub MoveToFirstPage()
            SetDataSource(False)
            ToolStripHelper.MoveToFirst(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem)
        End Sub

        Private Sub MoveToPrevious()
            SetDataSource(False)
            ToolStripHelper.MoveToPrevious(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentRecordNumber)
        End Sub

        Private Sub MoveToNext()
            SetDataSource(False)
            ToolStripHelper.MoveToNext(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem, _currentPageNumber, _totalNumberOfPages)
        End Sub

        Private Sub MoveToLastPage()
            SetDataSource(False)
            ToolStripHelper.MoveToLast(BnvNavMoveFirstItem, BnvNavMovePreviousItem, BnvNavMoveNextItem, BnvNavMoveLastItem)
        End Sub

        Private Sub SetDataSource(isSort As Boolean)
            If isSort Then
                _sortByExpression = GetSortByExpression()
            End If

            ' fill the datagridview
            DgvGrid.DataSource = OrdersQry.SelectSkipAndTake(ConstantHelper.GridNumberOfRows, _currentRecordNumber, _totalRecords, _sortByExpression)
            DgvGrid.Columns(_sortColumnIndex).HeaderCell.SortGlyphDirection = _sortOrder

            If _totalRecords > 0 Then
                _totalNumberOfPages = CInt(Math.Ceiling(CSng(_totalRecords) / CSng(ConstantHelper.GridNumberOfRows)))
                TscbPage.ComboBox.Items.Clear()

                ' fill page numbers in toolstripcombobox
                For page As Integer = 1 To _totalNumberOfPages
                    _isFireToolStripComboBoxSelectedIndexChanged = False
                    TscbPage.ComboBox.Items.Add(page)
                Next

                TscbPage.ComboBox.SelectedItem = _currentPageNumber
                _isFireToolStripComboBoxSelectedIndexChanged = True
            End If

            ResetNavButtonsToDefault()
        End Sub

        Private Function GetSortByExpression() As String
            _sortOrder = SortOrder.Descending

            Select Case _sortColumnIndex
                Case 0
                    If _sortByExpression = "OrderID" Then
                        Return "OrderID desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "OrderID"

                Case 1
                    If _sortByExpression = "CustomerID" Then
                        Return "CustomerID desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "CustomerID"

                Case 2
                    If _sortByExpression = "EmployeeID" Then
                        Return "EmployeeID desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "EmployeeID"

                Case 3
                    If _sortByExpression = "OrderDate" Then
                        Return "OrderDate desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "OrderDate"

                Case 4
                    If _sortByExpression = "RequiredDate" Then
                        Return "RequiredDate desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "RequiredDate"

                Case 5
                    If _sortByExpression = "ShippedDate" Then
                        Return "ShippedDate desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShippedDate"

                Case 6
                    If _sortByExpression = "ShipVia" Then
                        Return "ShipVia desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipVia"

                Case 7
                    If _sortByExpression = "Freight" Then
                        Return "Freight desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "Freight"

                Case 8
                    If _sortByExpression = "ShipName" Then
                        Return "ShipName desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipName"

                Case 9
                    If _sortByExpression = "ShipAddress" Then
                        Return "ShipAddress desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipAddress"

                Case 10
                    If _sortByExpression = "ShipCity" Then
                        Return "ShipCity desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipCity"

                Case 11
                    If _sortByExpression = "ShipRegion" Then
                        Return "ShipRegion desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipRegion"

                Case 12
                    If _sortByExpression = "ShipPostalCode" Then
                        Return "ShipPostalCode desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipPostalCode"

                Case 13
                    If _sortByExpression = "ShipCountry" Then
                        Return "ShipCountry desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "ShipCountry"

                Case 14
                    If _sortByExpression = "CompanyName" Then
                        Return "CompanyName desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "CompanyName"

                Case 15
                    If _sortByExpression = "Address" Then
                        Return "Address desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "Address"

                Case 16
                    If _sortByExpression = "City" Then
                        Return "City desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "City"

                Case 17
                    If _sortByExpression = "Region1" Then
                        Return "Region1 desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "Region1"

                Case 18
                    If _sortByExpression = "PostalCode" Then
                        Return "PostalCode desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "PostalCode"

                Case 19
                    If _sortByExpression = "Country" Then
                        Return "Country desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return "Country"

                Case Else
                    If _sortByExpression = "" Then
                        Return " desc"
                    End If

                    _sortOrder = SortOrder.Ascending
                    Return ""
            End Select
        End Function

        Private Sub ResetNavButtonsToDefault()
            BnvNavCountItem.Text = "of " & _totalNumberOfPages & " pages"

            If _totalRecords <= ConstantHelper.GridNumberOfRows Then
                BnvNavMoveNextItem.Enabled = False
                BnvNavMoveLastItem.Enabled = False
            Else
                BnvNavMoveNextItem.Enabled = True
                BnvNavMoveLastItem.Enabled = True
            End If
        End Sub

        Private Sub HightlightRow(rowIndex As Integer)
            ' highlight row
            DgvGrid.ClearSelection()
            DgvGrid.Rows(rowIndex).Selected = True

            ' remember the current row clicked by the user
            _currentRowIndex = rowIndex
        End Sub


        #End Region
    End Class
